@@ -47,6 +47,11 @@ detect_from_os_release()
 		return
 	fi
 	
+	if [ "$os_id" = 'debian' ] && printf -- '%s\n' "$version_id" | grep -Eqe '^9$'; then
+		printf -- '%s\n' 'DEBIAN9'
+		return
+	fi
+	
 	if [ "$os_id" = 'debian' ] && printf -- '%s\n' "$version_id" | grep -Eqe '^10$'; then
 		printf -- '%s\n' 'DEBIAN10'
 		return
@@ -62,11 +67,6 @@ detect_from_os_release()
 		return
 	fi
 	
-	if [ "$os_id" = 'debian' ] && printf -- '%s\n' "$version_id" | grep -Eqe '^9$'; then
-		printf -- '%s\n' 'DEBIAN9'
-		return
-	fi
-	
 	if [ "$os_id" = 'ol' ] && printf -- '%s\n' "$version_id" | grep -Eqe '^7(?:$|\.[0-9])'; then
 		printf -- '%s\n' 'ORACLE7'
 		return
@@ -256,6 +256,7 @@ show_ALMA8()
       ]
     }
   },
+  "descr": "AlmaLinux 8.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "alma",
@@ -351,6 +352,7 @@ show_CENTOS6()
       ]
     }
   },
+  "descr": "CentOS 6.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "centos",
@@ -446,6 +448,7 @@ show_CENTOS7()
       ]
     }
   },
+  "descr": "CentOS 7.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "centos",
@@ -545,6 +548,7 @@ show_CENTOS8()
       ]
     }
   },
+  "descr": "CentOS 8.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "centos",
@@ -579,6 +583,118 @@ show_CENTOS8()
 EOVARIANT_JSON
 }
 
+show_DEBIAN9()
+{
+	cat <<'EOVARIANT_JSON'
+  {
+  "builder": {
+    "alias": "debian9",
+    "base_image": "debian:stretch",
+    "branch": "debian/stretch",
+    "kernel_package": "linux-headers",
+    "utf8_locale": "C.UTF-8"
+  },
+  "commands": {
+    "package": {
+      "install": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "--no-install-recommends",
+        "install",
+        "--"
+      ],
+      "list_all": [
+        "dpkg-query",
+        "-W",
+        "-f",
+        "${Package}\\t${Version}\\t${Architecture}\\t${db:Status-Abbrev}\\n",
+        "--"
+      ],
+      "purge": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "purge",
+        "--"
+      ],
+      "remove": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "remove",
+        "--"
+      ],
+      "remove_impl": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "dpkg",
+        "-r",
+        "--"
+      ],
+      "update_db": [
+        "apt-get",
+        "-q",
+        "-y",
+        "update"
+      ]
+    },
+    "pkgfile": {
+      "dep_query": [
+        "sh",
+        "-c",
+        "dpkg-deb -f -- \"$pkg\" 'Depends' | sed -e 's/ *, */,/g' | tr ',' \"\\n\""
+      ],
+      "install": [
+        "sh",
+        "-c",
+        "env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages"
+      ]
+    }
+  },
+  "descr": "Debian 9.x (stretch)",
+  "detect": {
+    "filename": "/etc/os-release",
+    "os_id": "debian",
+    "os_version_regex": "^9$",
+    "regex": "^\n                    PRETTY_NAME= .*\n                    Debian \\s+ GNU/Linux \\s+\n                    (?: stretch | 9 ) (?: \\s | / )\n                "
+  },
+  "family": "debian",
+  "file_ext": "deb",
+  "initramfs_flavor": "update-initramfs",
+  "min_sys_python": "2.7",
+  "name": "DEBIAN9",
+  "package": {
+    "BINDINGS_PYTHON": "python",
+    "BINDINGS_PYTHON_CONFGET": "python-confget",
+    "BINDINGS_PYTHON_SIMPLEJSON": "python-simplejson",
+    "CGROUP": "cgroup-tools",
+    "CPUPOWER": "linux-cpupower",
+    "LIBSSL": "libssl1.1",
+    "MCELOG": "mcelog"
+  },
+  "parent": "DEBIAN10",
+  "repo": {
+    "codename": "stretch",
+    "keyring": "debian/repo/storpool-keyring.gpg",
+    "req_packages": [
+      "apt-transport-https",
+      "ca-certificates"
+    ],
+    "sources": "debian/repo/storpool.sources",
+    "vendor": "debian"
+  },
+  "systemd_lib": "lib/systemd/system"
+}
+EOVARIANT_JSON
+}
+
 show_DEBIAN10()
 {
 	cat <<'EOVARIANT_JSON'
@@ -654,6 +770,7 @@ show_DEBIAN10()
       ]
     }
   },
+  "descr": "Debian 10.x (buster)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "debian",
@@ -764,6 +881,7 @@ show_DEBIAN11()
       ]
     }
   },
+  "descr": "Debian 11.x (bullseye)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "debian",
@@ -874,6 +992,7 @@ show_DEBIAN12()
       ]
     }
   },
+  "descr": "Debian 12.x (bookworm/unstable)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "debian",
@@ -909,117 +1028,6 @@ show_DEBIAN12()
 EOVARIANT_JSON
 }
 
-show_DEBIAN9()
-{
-	cat <<'EOVARIANT_JSON'
-  {
-  "builder": {
-    "alias": "debian9",
-    "base_image": "debian:stretch",
-    "branch": "debian/stretch",
-    "kernel_package": "linux-headers",
-    "utf8_locale": "C.UTF-8"
-  },
-  "commands": {
-    "package": {
-      "install": [
-        "env",
-        "DEBIAN_FRONTEND=noninteractive",
-        "apt-get",
-        "-q",
-        "-y",
-        "--no-install-recommends",
-        "install",
-        "--"
-      ],
-      "list_all": [
-        "dpkg-query",
-        "-W",
-        "-f",
-        "${Package}\\t${Version}\\t${Architecture}\\t${db:Status-Abbrev}\\n",
-        "--"
-      ],
-      "purge": [
-        "env",
-        "DEBIAN_FRONTEND=noninteractive",
-        "apt-get",
-        "-q",
-        "-y",
-        "purge",
-        "--"
-      ],
-      "remove": [
-        "env",
-        "DEBIAN_FRONTEND=noninteractive",
-        "apt-get",
-        "-q",
-        "-y",
-        "remove",
-        "--"
-      ],
-      "remove_impl": [
-        "env",
-        "DEBIAN_FRONTEND=noninteractive",
-        "dpkg",
-        "-r",
-        "--"
-      ],
-      "update_db": [
-        "apt-get",
-        "-q",
-        "-y",
-        "update"
-      ]
-    },
-    "pkgfile": {
-      "dep_query": [
-        "sh",
-        "-c",
-        "dpkg-deb -f -- \"$pkg\" 'Depends' | sed -e 's/ *, */,/g' | tr ',' \"\\n\""
-      ],
-      "install": [
-        "sh",
-        "-c",
-        "env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages"
-      ]
-    }
-  },
-  "detect": {
-    "filename": "/etc/os-release",
-    "os_id": "debian",
-    "os_version_regex": "^9$",
-    "regex": "^\n                    PRETTY_NAME= .*\n                    Debian \\s+ GNU/Linux \\s+\n                    (?: stretch | 9 ) (?: \\s | / )\n                "
-  },
-  "family": "debian",
-  "file_ext": "deb",
-  "initramfs_flavor": "update-initramfs",
-  "min_sys_python": "2.7",
-  "name": "DEBIAN9",
-  "package": {
-    "BINDINGS_PYTHON": "python",
-    "BINDINGS_PYTHON_CONFGET": "python-confget",
-    "BINDINGS_PYTHON_SIMPLEJSON": "python-simplejson",
-    "CGROUP": "cgroup-tools",
-    "CPUPOWER": "linux-cpupower",
-    "LIBSSL": "libssl1.1",
-    "MCELOG": "mcelog"
-  },
-  "parent": "DEBIAN10",
-  "repo": {
-    "codename": "stretch",
-    "keyring": "debian/repo/storpool-keyring.gpg",
-    "req_packages": [
-      "apt-transport-https",
-      "ca-certificates"
-    ],
-    "sources": "debian/repo/storpool.sources",
-    "vendor": "debian"
-  },
-  "systemd_lib": "lib/systemd/system"
-}
-EOVARIANT_JSON
-}
-
 show_ORACLE7()
 {
 	cat <<'EOVARIANT_JSON'
@@ -1081,6 +1089,7 @@ show_ORACLE7()
       ]
     }
   },
+  "descr": "Oracle Linux 7.x",
   "detect": {
     "filename": "/etc/oracle-release",
     "os_id": "ol",
@@ -1180,6 +1189,7 @@ show_RHEL8()
       ]
     }
   },
+  "descr": "RedHat Enterprise Linux 8.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "rhel",
@@ -1279,6 +1289,7 @@ show_ROCKY8()
       ]
     }
   },
+  "descr": "Rocky Linux 8.x",
   "detect": {
     "filename": "/etc/redhat-release",
     "os_id": "rocky",
@@ -1388,6 +1399,7 @@ show_UBUNTU1604()
       ]
     }
   },
+  "descr": "Ubuntu 16.04 LTS (Xenial Xerus)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "ubuntu",
@@ -1500,6 +1512,7 @@ show_UBUNTU1804()
       ]
     }
   },
+  "descr": "Ubuntu 18.04 LTS (Bionic Beaver)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "ubuntu",
@@ -1610,6 +1623,7 @@ show_UBUNTU2004()
       ]
     }
   },
+  "descr": "Ubuntu 20.04 LTS (Focal Fossa)",
   "detect": {
     "filename": "/etc/os-release",
     "os_id": "ubuntu",
@@ -1658,7 +1672,7 @@ cmd_show_all()
   "format": {
     "version": {
       "major": 1,
-      "minor": 2
+      "minor": 3
     }
   },
   "order": [
@@ -1693,6 +1707,9 @@ EOPROLOGUE
   printf -- '    "%s": ' 'CENTOS8'
   show_CENTOS8
   echo ','
+  printf -- '    "%s": ' 'DEBIAN9'
+  show_DEBIAN9
+  echo ','
   printf -- '    "%s": ' 'DEBIAN10'
   show_DEBIAN10
   echo ','
@@ -1702,9 +1719,6 @@ EOPROLOGUE
   printf -- '    "%s": ' 'DEBIAN12'
   show_DEBIAN12
   echo ','
-  printf -- '    "%s": ' 'DEBIAN9'
-  show_DEBIAN9
-  echo ','
   printf -- '    "%s": ' 'ORACLE7'
   show_ORACLE7
   echo ','
@@ -1726,7 +1740,7 @@ EOPROLOGUE
 
 	cat <<'EOEPILOGUE'
   },
-  "version": "1.3.0"
+  "version": "2.0.0"
 }
 EOEPILOGUE
 }
@@ -1740,7 +1754,7 @@ show_variant()
   "format": {
     "version": {
       "major": 1,
-      "minor": 2
+      "minor": 3
     }
   },
   "variant":
@@ -1750,7 +1764,7 @@ EOPROLOGUE
 
 	cat <<'EOEPILOGUE'
   ,
-  "version": "1.3.0"
+  "version": "2.0.0"
 }
 EOEPILOGUE
 }
@@ -2109,6 +2123,71 @@ fi
 			esac
 			;;
 		
+		DEBIAN9)
+			case "$cmd_cat" in
+				
+				package)
+					case "$cmd_item" in
+						
+						install)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' '--no-install-recommends' 'install' '--'  "$@"
+							;;
+						
+						list_all)
+							$noop 'dpkg-query' '-W' '-f' '${Package}\t${Version}\t${Architecture}\t${db:Status-Abbrev}\n' '--'  "$@"
+							;;
+						
+						purge)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'purge' '--'  "$@"
+							;;
+						
+						remove)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'remove' '--'  "$@"
+							;;
+						
+						remove_impl)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'dpkg' '-r' '--'  "$@"
+							;;
+						
+						update_db)
+							$noop 'apt-get' '-q' '-y' 'update'  "$@"
+							;;
+						
+
+						*)
+							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
+							exit 1
+							;;
+					esac
+					;;
+				
+				pkgfile)
+					case "$cmd_item" in
+						
+						dep_query)
+							$noop 'sh' '-c' 'dpkg-deb -f -- "$pkg" 'Depends' | sed -e 's/ *, */,/g' | tr ',' "\n"'  "$@"
+							;;
+						
+						install)
+							$noop 'sh' '-c' 'env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages'  "$@"
+							;;
+						
+
+						*)
+							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
+							exit 1
+							;;
+					esac
+					;;
+				
+
+				*)
+					echo "Invalid command category '$cmd_cat'" 1>&2
+					exit 1
+					;;
+			esac
+			;;
+		
 		DEBIAN10)
 			case "$cmd_cat" in
 				
@@ -2304,71 +2383,6 @@ fi
 			esac
 			;;
 		
-		DEBIAN9)
-			case "$cmd_cat" in
-				
-				package)
-					case "$cmd_item" in
-						
-						install)
-							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' '--no-install-recommends' 'install' '--'  "$@"
-							;;
-						
-						list_all)
-							$noop 'dpkg-query' '-W' '-f' '${Package}\t${Version}\t${Architecture}\t${db:Status-Abbrev}\n' '--'  "$@"
-							;;
-						
-						purge)
-							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'purge' '--'  "$@"
-							;;
-						
-						remove)
-							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'remove' '--'  "$@"
-							;;
-						
-						remove_impl)
-							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'dpkg' '-r' '--'  "$@"
-							;;
-						
-						update_db)
-							$noop 'apt-get' '-q' '-y' 'update'  "$@"
-							;;
-						
-
-						*)
-							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
-							exit 1
-							;;
-					esac
-					;;
-				
-				pkgfile)
-					case "$cmd_item" in
-						
-						dep_query)
-							$noop 'sh' '-c' 'dpkg-deb -f -- "$pkg" 'Depends' | sed -e 's/ *, */,/g' | tr ',' "\n"'  "$@"
-							;;
-						
-						install)
-							$noop 'sh' '-c' 'env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages'  "$@"
-							;;
-						
-
-						*)
-							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
-							exit 1
-							;;
-					esac
-					;;
-				
-
-				*)
-					echo "Invalid command category '$cmd_cat'" 1>&2
-					exit 1
-					;;
-			esac
-			;;
-		
 		ORACLE7)
 			case "$cmd_cat" in
 				
@@ -2873,6 +2887,8 @@ repo_add_yum()
 {
 	local name="$1" vdir="$2" repotype="$3" yumdef="$4" keyring="$5"
 
+	yum --disablerepo='storpool-*' install -q -y ca-certificates
+
 	local yumbase="$(basename -- "$yumdef")"
 	local repofile="$(repo_add_extension "$yumbase" "$repotype")"
 	[ -n "$repofile" ]
@@ -2965,6 +2981,12 @@ cmd_repo_add()
 			
 			;;
 		
+		DEBIAN9)
+			
+			repo_add_deb 'DEBIAN9' "$vdir" "$repotype" 'debian/repo/storpool.sources' 'debian/repo/storpool-keyring.gpg' 'apt-transport-https ca-certificates'
+			
+			;;
+		
 		DEBIAN10)
 			
 			repo_add_deb 'DEBIAN10' "$vdir" "$repotype" 'debian/repo/storpool.sources' 'debian/repo/storpool-keyring.gpg' 'ca-certificates'
@@ -2983,12 +3005,6 @@ cmd_repo_add()
 			
 			;;
 		
-		DEBIAN9)
-			
-			repo_add_deb 'DEBIAN9' "$vdir" "$repotype" 'debian/repo/storpool.sources' 'debian/repo/storpool-keyring.gpg' 'apt-transport-https ca-certificates'
-			
-			;;
-		
 		ORACLE7)
 			
 			repo_add_yum 'ORACLE7' "$vdir" "$repotype" 'redhat/repo/storpool-centos.repo' 'redhat/repo/RPM-GPG-KEY-StorPool'
@@ -3026,6 +3042,8 @@ cmd_repo_add()
 			;;
 		
 	esac
+
+	install -o root -g root -m 755 -- "$0" /usr/sbin/sp_variant
 }
 
 cmd_command_run()
@@ -3068,7 +3086,7 @@ cmd_command()
 
 cmd_features()
 {
-	echo 'Features: format=1.2 version=1.3.0'
+	echo 'Features: format=1.3 version=2.0.0'
 }
 
 case "$1" in
@@ -3132,6 +3150,10 @@ case "$1" in
 				show_variant 'CENTOS8'
 				;;
 			
+			DEBIAN9)
+				show_variant 'DEBIAN9'
+				;;
+			
 			DEBIAN10)
 				show_variant 'DEBIAN10'
 				;;
@@ -3144,10 +3166,6 @@ case "$1" in
 				show_variant 'DEBIAN12'
 				;;
 			
-			DEBIAN9)
-				show_variant 'DEBIAN9'
-				;;
-			
 			ORACLE7)
 				show_variant 'ORACLE7'
 				;;
